﻿
/*
* Copyright (C) 2013 cnblogs.com All Rights Reserved 
*
* Description : Json字串解析成字典
* Auther      : gateluck
* CreateDate  : 2013-08-27
* History     : 
*/
using System;
using System.Collections.Generic;
using System.Text;
using System.Web.Script.Serialization;

namespace JsonUtils
{
    public class JsonObject
    {
        /// <summary>
        /// 解析JSON字串
        /// </summary>
        public static JsonObject Parse(string json)
        {
            var js = new JavaScriptSerializer();

            object obj = js.DeserializeObject(json);

            return Cast(obj);
        }

        /// <summary>
        /// 将普通字典类型转为JsonObject
        /// </summary>
        private static JsonObject Cast(object value)
        {
            var obj = new JsonObject();

            //如果是数组
            if (value is object[])
            {

                List<JsonObject> list = new List<JsonObject>();

                object[] array = (object[])value;
                for (int i = 0; i < array.Length; i++)
                {
                    list.Add(Cast(array[i]));
                }
                obj.Value = list.ToArray();
            }
            //如果是字典
            else if (value is Dictionary<string, object>)
            {
                var dict = value as Dictionary<string, object>;
                var dict2 = new Dictionary<string, JsonObject>();
                foreach (var entry in dict)
                {
                    dict2.Add(entry.Key, Cast(entry.Value));
                }
                obj.Value = dict2;
            }
            //如果是普通类
            else
            {
                obj.Value = value;
            }
            return obj;
        }

        /// <summary>
        /// 取对象的属性
        /// </summary>
        public JsonObject this[string key]
        {
            get
            {
                var dict = this.Value as Dictionary<string, JsonObject>;
                if (dict != null && dict.ContainsKey(key))
                {
                    return dict[key];
                }

                return new JsonObject();
            }

        }
        /// <summary>
        /// 取数组
        /// </summary>
        public JsonObject this[int index]
        {
            get
            {
                var array = this.Value as JsonObject[];
                if (array != null && array.Length > index)
                {
                    return array[index];
                }
                return new JsonObject();
            }

        }

        /// <summary>
        /// 将值以希望类型取出
        /// </summary>
        public T GetValue<T>()
        {
            return (T)Convert.ChangeType(Value, typeof(T));
        }

        /// <summary>
        /// 取出字串类型的值
        /// </summary>
        public string Text()
        {
            return Convert.ToString(Value);
        }

        /// <summary>
        /// 取出数值
        /// </summary>
        public double Number()
        {
            return Convert.ToDouble(Value);
        }

        /// <summary>
        /// 取出整型
        /// </summary>
        public int Integer()
        {
            return Convert.ToInt32(Value);
        }

        /// <summary>
        /// 取出布尔型
        /// </summary>
        public bool Boolean()
        {
            return Convert.ToBoolean(Value);
        }


        /// <summary>
        /// 值
        /// </summary>
        public object Value
        {
            get;
            private set;
        }

        /// <summary>
        /// 如果是数组返回数组长度
        /// </summary>
        public int Length
        {
            get
            {
                var array = this.Value as JsonObject[];
                if (array != null)
                {
                    return array.Length;
                }
                return 0;
            }
        }
    }
}




